@@ -4,8 +4,11 @@ discretePlot <- function(x, by, scale=c("frequency", "percent"), xlab=deparse(su
     dp <- function(x, scale, xlab, ylab, main, xlim=range(x), ylim=c(0, max(y))){
         y <- as.vector(table(x))
         if (scale == "percent") y <- 100*y/sum(y)
-        x <- unique(x)
-        plot(x, y, type="h", xlab=xlab, ylab=ylab, main=main, xlim=xlim, ylim=ylim)
+        x <- sort(unique(x))
+        plot(x, y, type="h", xlab=xlab, ylab=ylab, main=main, xlim=xlim, ylim=ylim,
+             axes=FALSE, frame.plot=TRUE)
+        axis(2)
+        axis(1, at=x)
         points(x, y, pch=16)
         abline(h=0, col="gray")
     }
@@ -14,6 +17,12 @@ discretePlot <- function(x, by, scale=c("frequency", "percent"), xlab=deparse(su
     }
     else{
         by.var <- deparse(substitute(by))
+        if (!is.factor(by)){
+            if (!(is.character(by) || is.logical(by))){
+                stop("by must be a factor, character, or logical")
+            }
+            by <- as.factor(by)
+        }
         complete <- complete.cases(x, by)
         x <- x[complete]
         by <- by[complete]
